@@ -26,8 +26,6 @@ from ipywidgets import widgets
 from IPython.display import HTML,Javascript, display
 
 pd.options.mode.chained_assignment = None
-from deshaw.djs import TidyReport
-
 
 # ### Data Cleaning
 
@@ -880,21 +878,6 @@ def addQuantileCol(
 # ## Errors
 
 # In[9]:
-
-
-def Notify(
-        user,
-        warning,
-        filepath,
-        message = None,
-        title = "[djserror] DJS Python Error Report"):
-    report = TidyReport([f"{warning} error at {filepath}",
-                          f"{message}"])
-    report.mail(
-            to = user,
-            subject = title,
-            attach_html_report = False
-        )
     
 def popup(text):
     """
